<?php

header('Content-Type: application/json; charset=utf-8');

require_once '../constants.php';
require '../vendor/autoload.php'; // Change path as needed

use GuzzleHttp\Client;

function fetchFacebookPosts($accessToken, $pageId)
{
    $client = new Client([
        'base_uri' => 'https://graph.facebook.com/v12.0/', // Use the latest version available
    ]);

    try
    {
        // Send a GET request to fetch posts
        $response = $client->request('GET', "$pageId/posts", [
            'query' => [
                'access_token' => $accessToken,
                'fields' => 'id,message,attachments{media_type,url,subattachments{media{image}}},likes.summary(true),shares',
            ]
        ]);

        // Decode the JSON response
        $posts = json_decode($response->getBody(), true);

        // echo "<pre>";
        // print_r($posts);

        // Return posts data or an empty array if no posts found
        return isset($posts['data']) ? $posts['data'] : [];
    }
    catch (GuzzleHttp\Exception\RequestException $e)
    {
        // Handle the exception (optionally log the error)
        echo 'HTTP Request failed: ' . $e->getMessage() . PHP_EOL;
        return []; // Return an empty array on error
    }
}

// Example usage
$appId = APP_ID;
$appSecret = APP_SECRET;
$accessToken = file_get_contents('page_token.txt');
$pageId = PAGE_ID;

if (empty($accessToken))
{
    die("Token not found");
}

$posts = fetchFacebookPosts($accessToken, $pageId);

$response_data = [
    'status' => false,
    'message' => 'No post found',
    'data' => []
];

// Example to show the output
if (!empty($posts))
{
    foreach ($posts as $post)
    {
        $posts_arr[] = [
            'post_id' => $post['id'],
            'post_message' => $post['message'],
            'post_attachments' => $post['attachments']
        ];
    }

    $response_data['status'] = true;
    $response_data['message'] = 'Post found';
    $response_data['data'] = $posts_arr;

    // echo json_encode($response_data);
}

echo json_encode($response_data);
